# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trade/trade_stock.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from trade import trade_enum_pb2 as trade_dot_trade__enum__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='trade/trade_stock.proto',
  package='trade.stock',
  syntax='proto3',
  serialized_options=_b('\242\002\003TST'),
  serialized_pb=_b('\n\x17trade/trade_stock.proto\x12\x0btrade.stock\x1a\x16trade/trade_enum.proto\"\x80\x01\n\rQueryOrderReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x12\n\nbegin_time\x18\x04 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x03\x12\x14\n\x0cinvestor_key\x18\x06 \x01(\x04\"\x93\x01\n\x0eQueryReportReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x10\n\x08trade_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12\x12\n\nbegin_time\x18\x05 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x03\x12\x14\n\x0cinvestor_key\x18\x07 \x01(\x04\"8\n\rQueryAssetReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x02 \x01(\x04\"\x8a\x04\n\rQueryAssetRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12)\n\x08\x63urrency\x18\x02 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x14\n\x0c\x62\x65gin_amount\x18\x03 \x01(\x01\x12\x0f\n\x07\x64\x65posit\x18\x04 \x01(\x01\x12\x10\n\x08withdraw\x18\x05 \x01(\x01\x12\x16\n\x0e\x63urrent_amount\x18\x06 \x01(\x01\x12\x14\n\x0ctotal_amount\x18\x07 \x01(\x01\x12\x11\n\tavailable\x18\x08 \x01(\x01\x12\x14\n\x0cwithdrawable\x18\t \x01(\x01\x12\x18\n\x10total_buy_amount\x18\n \x01(\x01\x12\x15\n\rtotal_buy_fee\x18\x0b \x01(\x01\x12\x19\n\x11total_sell_amount\x18\x0c \x01(\x01\x12\x16\n\x0etotal_sell_fee\x18\r \x01(\x01\x12\x15\n\rfrozen_margin\x18\x0e \x01(\x01\x12\x15\n\rcaptial_asset\x18\x0f \x01(\x01\x12\x16\n\x0esecurity_asset\x18\x10 \x01(\x01\x12\x14\n\x0c\x63lose_profit\x18\x11 \x01(\x01\x12\x12\n\ncommission\x18\x12 \x01(\x01\x12\x17\n\x0fposition_profit\x18\x13 \x01(\x01\x12\x14\n\x0c\x66loat_profit\x18\x14 \x01(\x01\x12\x12\n\nin_transit\x18\x15 \x01(\x01\x12\x14\n\x0cinvestor_key\x18\x16 \x01(\x04\"K\n\x10QueryPositionReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x03 \x01(\x04\"\xcc\x03\n\x10QueryPositionRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x14\n\x0cstock_holder\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x13\n\x0bsymbol_name\x18\x04 \x01(\x0c\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\x16\n\x0equantity_begin\x18\x06 \x01(\x03\x12\x1d\n\x15quantity_begin_frozen\x18\x07 \x01(\x03\x12\x1a\n\x12quantity_buy_today\x18\x08 \x01(\x03\x12!\n\x19quantity_buy_frozen_today\x18\t \x01(\x03\x12\x1b\n\x13quantity_sell_today\x18\n \x01(\x03\x12\"\n\x1aquantity_sell_frozen_today\x18\x0b \x01(\x03\x12\x1a\n\x12quantity_available\x18\x0c \x01(\x03\x12\x18\n\x10quantity_current\x18\r \x01(\x03\x12\x12\n\nlast_price\x18\x0e \x01(\x01\x12\x12\n\ncost_price\x18\x0f \x01(\x01\x12\x14\n\x0c\x66loat_profit\x18\x10 \x01(\x01\x12\x14\n\x0cinvestor_key\x18\x11 \x01(\x04\"\x82\x04\n\x0eOrderInsertReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\r\n\x05price\x18\x06 \x01(\x01\x12\x10\n\x08quantity\x18\x07 \x01(\x03\x12(\n\nprice_type\x18\x08 \x01(\x0e\x32\x14.trade.tag.PriceType\x12%\n\x06\x61\x63tion\x18\t \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\n \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x14\n\x0corder_source\x18\x0b \x01(\t\x12(\n\norder_type\x18\x0c \x01(\x0e\x32\x14.trade.tag.OrderType\x12\x14\n\x0cinvestor_key\x18\r \x01(\x04\x12\x16\n\x0einstruction_id\x18\x0e \x01(\x03\x12\x14\n\x0cportfolio_id\x18\x0f \x01(\x03\x12\x10\n\x08\x63ombi_no\x18\x10 \x01(\x03\x12\x0f\n\x07user_id\x18\x11 \x01(\t\x12\x17\n\x0forder_deal_flag\x18\x12 \x01(\x03\x12\x16\n\x0einstitution_id\x18\x13 \x01(\x03\"\xf0\x03\n\x0eOrderInsertRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\r\n\x05price\x18\x06 \x01(\x01\x12\x10\n\x08quantity\x18\x07 \x01(\x03\x12(\n\nprice_type\x18\x08 \x01(\x0e\x32\x14.trade.tag.PriceType\x12%\n\x06\x61\x63tion\x18\t \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\n \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x14\n\x0corder_source\x18\x0b \x01(\t\x12(\n\norder_type\x18\x0c \x01(\x0e\x32\x14.trade.tag.OrderType\x12\x0c\n\x04\x63ode\x18\r \x01(\x05\x12\x0f\n\x07message\x18\x0e \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x0f \x01(\x04\x12\x16\n\x0einstruction_id\x18\x10 \x01(\x03\x12\x14\n\x0cportfolio_id\x18\x11 \x01(\x03\x12\x10\n\x08\x63ombi_no\x18\x12 \x01(\x03\x12\x0f\n\x07user_id\x18\x13 \x01(\t\"\xae\x01\n\x0eOrderCancelReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x1d\n\x15local_cancel_order_no\x18\x03 \x01(\t\x12\x17\n\x0f\x63\x61ncel_order_no\x18\x04 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x05 \x01(\x04\x12)\n\x08\x65xchange\x18\x06 \x01(\x0e\x32\x17.trade.tag.ExchangeType\"\xa2\x01\n\x0eOrderCancelRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61ncel_order_no\x18\x03 \x01(\t\x12\x1d\n\x15local_cancel_order_no\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x06 \x01(\x05\x12\x14\n\x0cinvestor_key\x18\x07 \x01(\x04\"`\n\x13OrderCancelFailInfo\x12*\n\x05order\x18\x01 \x01(\x0b\x32\x1b.trade.stock.OrderCancelReq\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"\xf9\x06\n\tOrderInfo\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x02 \x01(\t\x12\x1d\n\x15local_cancel_order_no\x18\x03 \x01(\t\x12\x17\n\x0f\x63\x61ncel_order_no\x18\x04 \x01(\t\x12\x0e\n\x06symbol\x18\x05 \x01(\t\x12)\n\x08\x65xchange\x18\x06 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\r\n\x05price\x18\x07 \x01(\x01\x12\x10\n\x08quantity\x18\x08 \x01(\x03\x12(\n\nprice_type\x18\t \x01(\x0e\x32\x14.trade.tag.PriceType\x12%\n\x06\x61\x63tion\x18\n \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\x0b \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x17\n\x0fquantity_traded\x18\x0c \x01(\x03\x12\x15\n\rquantity_left\x18\r \x01(\x03\x12\x13\n\x0binsert_time\x18\x0e \x01(\x03\x12\x13\n\x0bupdate_time\x18\x0f \x01(\x03\x12\x13\n\x0b\x63\x61ncel_time\x18\x10 \x01(\x03\x12\x15\n\rfrozen_margin\x18\x11 \x01(\x01\x12\x14\n\x0ctrade_amount\x18\x12 \x01(\x01\x12\x30\n\x0corder_status\x18\x13 \x01(\x0e\x32\x1a.trade.tag.OrderStatusType\x12(\n\norder_type\x18\x14 \x01(\x0e\x32\x14.trade.tag.OrderType\x12\x11\n\tclient_id\x18\x15 \x01(\t\x12\x0c\n\x04\x63ode\x18\x16 \x01(\x05\x12\x0f\n\x07message\x18\x17 \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x18 \x01(\x04\x12\x11\n\tavg_price\x18\x19 \x01(\x01\x12\x13\n\x0bsymbol_name\x18\x1a \x01(\x0c\x12\x16\n\x0einstruction_id\x18\x1b \x01(\x03\x12\x14\n\x0cportfolio_id\x18\x1c \x01(\x03\x12\x10\n\x08\x63ombi_no\x18\x1d \x01(\x03\x12\x0f\n\x07user_id\x18\x1e \x01(\t\x12\x18\n\x10\x66irst_trade_time\x18\x1f \x01(\x03\x12\x19\n\x11quantity_canceled\x18  \x01(\x03\x12\x16\n\x0einstitution_id\x18! \x01(\x03\x12\x0e\n\x06seq_no\x18\" \x01(\x03\x12\x17\n\x0forder_deal_flag\x18# \x01(\x03\"\xc9\x03\n\x0fTradeReportInfo\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\x10\n\x08trade_no\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\x01\x12\x10\n\x08quantity\x18\x08 \x01(\x03\x12\x12\n\ntrade_time\x18\t \x01(\x03\x12\x14\n\x0ctrade_amount\x18\n \x01(\x01\x12\x14\n\x0creport_index\x18\x0b \x01(\x04\x12(\n\ntrade_type\x18\x0c \x01(\x0e\x32\x14.trade.tag.TradeType\x12%\n\x06\x61\x63tion\x18\r \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\x0e \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x14\n\x0cinvestor_key\x18\x0f \x01(\x04\x12\x13\n\x0bsymbol_name\x18\x10 \x01(\x0c\x12\x0f\n\x07user_id\x18\x11 \x01(\t\x12\x0e\n\x06seq_no\x18\x12 \x01(\x03\x42\x06\xa2\x02\x03TSTb\x06proto3')
  ,
  dependencies=[trade_dot_trade__enum__pb2.DESCRIPTOR,])




_QUERYORDERREQ = _descriptor.Descriptor(
  name='QueryOrderReq',
  full_name='trade.stock.QueryOrderReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryOrderReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.QueryOrderReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryOrderReq.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_time', full_name='trade.stock.QueryOrderReq.begin_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='trade.stock.QueryOrderReq.end_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryOrderReq.investor_key', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=193,
)


_QUERYREPORTREQ = _descriptor.Descriptor(
  name='QueryReportReq',
  full_name='trade.stock.QueryReportReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryReportReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.QueryReportReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_no', full_name='trade.stock.QueryReportReq.trade_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryReportReq.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_time', full_name='trade.stock.QueryReportReq.begin_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='trade.stock.QueryReportReq.end_time', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryReportReq.investor_key', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=343,
)


_QUERYASSETREQ = _descriptor.Descriptor(
  name='QueryAssetReq',
  full_name='trade.stock.QueryAssetReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryAssetReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryAssetReq.investor_key', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=401,
)


_QUERYASSETRSP = _descriptor.Descriptor(
  name='QueryAssetRsp',
  full_name='trade.stock.QueryAssetRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryAssetRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency', full_name='trade.stock.QueryAssetRsp.currency', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_amount', full_name='trade.stock.QueryAssetRsp.begin_amount', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='trade.stock.QueryAssetRsp.deposit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdraw', full_name='trade.stock.QueryAssetRsp.withdraw', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_amount', full_name='trade.stock.QueryAssetRsp.current_amount', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_amount', full_name='trade.stock.QueryAssetRsp.total_amount', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='available', full_name='trade.stock.QueryAssetRsp.available', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawable', full_name='trade.stock.QueryAssetRsp.withdrawable', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_buy_amount', full_name='trade.stock.QueryAssetRsp.total_buy_amount', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_buy_fee', full_name='trade.stock.QueryAssetRsp.total_buy_fee', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_sell_amount', full_name='trade.stock.QueryAssetRsp.total_sell_amount', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_sell_fee', full_name='trade.stock.QueryAssetRsp.total_sell_fee', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_margin', full_name='trade.stock.QueryAssetRsp.frozen_margin', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='captial_asset', full_name='trade.stock.QueryAssetRsp.captial_asset', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security_asset', full_name='trade.stock.QueryAssetRsp.security_asset', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit', full_name='trade.stock.QueryAssetRsp.close_profit', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commission', full_name='trade.stock.QueryAssetRsp.commission', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_profit', full_name='trade.stock.QueryAssetRsp.position_profit', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_profit', full_name='trade.stock.QueryAssetRsp.float_profit', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_transit', full_name='trade.stock.QueryAssetRsp.in_transit', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryAssetRsp.investor_key', index=21,
      number=22, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=926,
)


_QUERYPOSITIONREQ = _descriptor.Descriptor(
  name='QueryPositionReq',
  full_name='trade.stock.QueryPositionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryPositionReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryPositionReq.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryPositionReq.investor_key', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=928,
  serialized_end=1003,
)


_QUERYPOSITIONRSP = _descriptor.Descriptor(
  name='QueryPositionRsp',
  full_name='trade.stock.QueryPositionRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryPositionRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stock_holder', full_name='trade.stock.QueryPositionRsp.stock_holder', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryPositionRsp.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol_name', full_name='trade.stock.QueryPositionRsp.symbol_name', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.QueryPositionRsp.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_begin', full_name='trade.stock.QueryPositionRsp.quantity_begin', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_begin_frozen', full_name='trade.stock.QueryPositionRsp.quantity_begin_frozen', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_buy_today', full_name='trade.stock.QueryPositionRsp.quantity_buy_today', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_buy_frozen_today', full_name='trade.stock.QueryPositionRsp.quantity_buy_frozen_today', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_sell_today', full_name='trade.stock.QueryPositionRsp.quantity_sell_today', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_sell_frozen_today', full_name='trade.stock.QueryPositionRsp.quantity_sell_frozen_today', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_available', full_name='trade.stock.QueryPositionRsp.quantity_available', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_current', full_name='trade.stock.QueryPositionRsp.quantity_current', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='trade.stock.QueryPositionRsp.last_price', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_price', full_name='trade.stock.QueryPositionRsp.cost_price', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_profit', full_name='trade.stock.QueryPositionRsp.float_profit', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryPositionRsp.investor_key', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1006,
  serialized_end=1466,
)


_ORDERINSERTREQ = _descriptor.Descriptor(
  name='OrderInsertReq',
  full_name='trade.stock.OrderInsertReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderInsertReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderInsertReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.OrderInsertReq.local_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.OrderInsertReq.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderInsertReq.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.OrderInsertReq.price', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.OrderInsertReq.quantity', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_type', full_name='trade.stock.OrderInsertReq.price_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.OrderInsertReq.action', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.OrderInsertReq.business_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_source', full_name='trade.stock.OrderInsertReq.order_source', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='trade.stock.OrderInsertReq.order_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderInsertReq.investor_key', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_id', full_name='trade.stock.OrderInsertReq.instruction_id', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portfolio_id', full_name='trade.stock.OrderInsertReq.portfolio_id', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combi_no', full_name='trade.stock.OrderInsertReq.combi_no', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.OrderInsertReq.user_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_deal_flag', full_name='trade.stock.OrderInsertReq.order_deal_flag', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='institution_id', full_name='trade.stock.OrderInsertReq.institution_id', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1469,
  serialized_end=1983,
)


_ORDERINSERTRSP = _descriptor.Descriptor(
  name='OrderInsertRsp',
  full_name='trade.stock.OrderInsertRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderInsertRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderInsertRsp.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.OrderInsertRsp.local_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.OrderInsertRsp.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderInsertRsp.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.OrderInsertRsp.price', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.OrderInsertRsp.quantity', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_type', full_name='trade.stock.OrderInsertRsp.price_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.OrderInsertRsp.action', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.OrderInsertRsp.business_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_source', full_name='trade.stock.OrderInsertRsp.order_source', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='trade.stock.OrderInsertRsp.order_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderInsertRsp.code', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderInsertRsp.message', index=13,
      number=14, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderInsertRsp.investor_key', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_id', full_name='trade.stock.OrderInsertRsp.instruction_id', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portfolio_id', full_name='trade.stock.OrderInsertRsp.portfolio_id', index=16,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combi_no', full_name='trade.stock.OrderInsertRsp.combi_no', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.OrderInsertRsp.user_id', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2482,
)


_ORDERCANCELREQ = _descriptor.Descriptor(
  name='OrderCancelReq',
  full_name='trade.stock.OrderCancelReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderCancelReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderCancelReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_cancel_order_no', full_name='trade.stock.OrderCancelReq.local_cancel_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_order_no', full_name='trade.stock.OrderCancelReq.cancel_order_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderCancelReq.investor_key', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderCancelReq.exchange', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2485,
  serialized_end=2659,
)


_ORDERCANCELRSP = _descriptor.Descriptor(
  name='OrderCancelRsp',
  full_name='trade.stock.OrderCancelRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderCancelRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderCancelRsp.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_order_no', full_name='trade.stock.OrderCancelRsp.cancel_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_cancel_order_no', full_name='trade.stock.OrderCancelRsp.local_cancel_order_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderCancelRsp.message', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderCancelRsp.code', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderCancelRsp.investor_key', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2824,
)


_ORDERCANCELFAILINFO = _descriptor.Descriptor(
  name='OrderCancelFailInfo',
  full_name='trade.stock.OrderCancelFailInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='trade.stock.OrderCancelFailInfo.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderCancelFailInfo.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderCancelFailInfo.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2826,
  serialized_end=2922,
)


_ORDERINFO = _descriptor.Descriptor(
  name='OrderInfo',
  full_name='trade.stock.OrderInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderInfo.order_no', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.OrderInfo.local_order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_cancel_order_no', full_name='trade.stock.OrderInfo.local_cancel_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_order_no', full_name='trade.stock.OrderInfo.cancel_order_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.OrderInfo.symbol', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderInfo.exchange', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.OrderInfo.price', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.OrderInfo.quantity', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_type', full_name='trade.stock.OrderInfo.price_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.OrderInfo.action', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.OrderInfo.business_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_traded', full_name='trade.stock.OrderInfo.quantity_traded', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_left', full_name='trade.stock.OrderInfo.quantity_left', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_time', full_name='trade.stock.OrderInfo.insert_time', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='trade.stock.OrderInfo.update_time', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_time', full_name='trade.stock.OrderInfo.cancel_time', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_margin', full_name='trade.stock.OrderInfo.frozen_margin', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.stock.OrderInfo.trade_amount', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_status', full_name='trade.stock.OrderInfo.order_status', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='trade.stock.OrderInfo.order_type', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderInfo.client_id', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderInfo.code', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderInfo.message', index=22,
      number=23, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderInfo.investor_key', index=23,
      number=24, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_price', full_name='trade.stock.OrderInfo.avg_price', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol_name', full_name='trade.stock.OrderInfo.symbol_name', index=25,
      number=26, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_id', full_name='trade.stock.OrderInfo.instruction_id', index=26,
      number=27, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portfolio_id', full_name='trade.stock.OrderInfo.portfolio_id', index=27,
      number=28, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combi_no', full_name='trade.stock.OrderInfo.combi_no', index=28,
      number=29, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.OrderInfo.user_id', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_trade_time', full_name='trade.stock.OrderInfo.first_trade_time', index=30,
      number=31, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_canceled', full_name='trade.stock.OrderInfo.quantity_canceled', index=31,
      number=32, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='institution_id', full_name='trade.stock.OrderInfo.institution_id', index=32,
      number=33, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='trade.stock.OrderInfo.seq_no', index=33,
      number=34, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_deal_flag', full_name='trade.stock.OrderInfo.order_deal_flag', index=34,
      number=35, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2925,
  serialized_end=3814,
)


_TRADEREPORTINFO = _descriptor.Descriptor(
  name='TradeReportInfo',
  full_name='trade.stock.TradeReportInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.TradeReportInfo.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.TradeReportInfo.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.TradeReportInfo.local_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.TradeReportInfo.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.TradeReportInfo.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_no', full_name='trade.stock.TradeReportInfo.trade_no', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.TradeReportInfo.price', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.TradeReportInfo.quantity', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time', full_name='trade.stock.TradeReportInfo.trade_time', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.stock.TradeReportInfo.trade_amount', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_index', full_name='trade.stock.TradeReportInfo.report_index', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_type', full_name='trade.stock.TradeReportInfo.trade_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.TradeReportInfo.action', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.TradeReportInfo.business_type', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.TradeReportInfo.investor_key', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol_name', full_name='trade.stock.TradeReportInfo.symbol_name', index=15,
      number=16, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.TradeReportInfo.user_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='trade.stock.TradeReportInfo.seq_no', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3817,
  serialized_end=4274,
)

_QUERYASSETRSP.fields_by_name['currency'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYPOSITIONRSP.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINSERTREQ.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINSERTREQ.fields_by_name['price_type'].enum_type = trade_dot_trade__enum__pb2._PRICETYPE
_ORDERINSERTREQ.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINSERTREQ.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
_ORDERINSERTREQ.fields_by_name['order_type'].enum_type = trade_dot_trade__enum__pb2._ORDERTYPE
_ORDERINSERTRSP.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINSERTRSP.fields_by_name['price_type'].enum_type = trade_dot_trade__enum__pb2._PRICETYPE
_ORDERINSERTRSP.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINSERTRSP.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
_ORDERINSERTRSP.fields_by_name['order_type'].enum_type = trade_dot_trade__enum__pb2._ORDERTYPE
_ORDERCANCELREQ.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERCANCELFAILINFO.fields_by_name['order'].message_type = _ORDERCANCELREQ
_ORDERINFO.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINFO.fields_by_name['price_type'].enum_type = trade_dot_trade__enum__pb2._PRICETYPE
_ORDERINFO.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINFO.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
_ORDERINFO.fields_by_name['order_status'].enum_type = trade_dot_trade__enum__pb2._ORDERSTATUSTYPE
_ORDERINFO.fields_by_name['order_type'].enum_type = trade_dot_trade__enum__pb2._ORDERTYPE
_TRADEREPORTINFO.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_TRADEREPORTINFO.fields_by_name['trade_type'].enum_type = trade_dot_trade__enum__pb2._TRADETYPE
_TRADEREPORTINFO.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_TRADEREPORTINFO.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
DESCRIPTOR.message_types_by_name['QueryOrderReq'] = _QUERYORDERREQ
DESCRIPTOR.message_types_by_name['QueryReportReq'] = _QUERYREPORTREQ
DESCRIPTOR.message_types_by_name['QueryAssetReq'] = _QUERYASSETREQ
DESCRIPTOR.message_types_by_name['QueryAssetRsp'] = _QUERYASSETRSP
DESCRIPTOR.message_types_by_name['QueryPositionReq'] = _QUERYPOSITIONREQ
DESCRIPTOR.message_types_by_name['QueryPositionRsp'] = _QUERYPOSITIONRSP
DESCRIPTOR.message_types_by_name['OrderInsertReq'] = _ORDERINSERTREQ
DESCRIPTOR.message_types_by_name['OrderInsertRsp'] = _ORDERINSERTRSP
DESCRIPTOR.message_types_by_name['OrderCancelReq'] = _ORDERCANCELREQ
DESCRIPTOR.message_types_by_name['OrderCancelRsp'] = _ORDERCANCELRSP
DESCRIPTOR.message_types_by_name['OrderCancelFailInfo'] = _ORDERCANCELFAILINFO
DESCRIPTOR.message_types_by_name['OrderInfo'] = _ORDERINFO
DESCRIPTOR.message_types_by_name['TradeReportInfo'] = _TRADEREPORTINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryOrderReq = _reflection.GeneratedProtocolMessageType('QueryOrderReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORDERREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryOrderReq)
  })
_sym_db.RegisterMessage(QueryOrderReq)

QueryReportReq = _reflection.GeneratedProtocolMessageType('QueryReportReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPORTREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryReportReq)
  })
_sym_db.RegisterMessage(QueryReportReq)

QueryAssetReq = _reflection.GeneratedProtocolMessageType('QueryAssetReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYASSETREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryAssetReq)
  })
_sym_db.RegisterMessage(QueryAssetReq)

QueryAssetRsp = _reflection.GeneratedProtocolMessageType('QueryAssetRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYASSETRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryAssetRsp)
  })
_sym_db.RegisterMessage(QueryAssetRsp)

QueryPositionReq = _reflection.GeneratedProtocolMessageType('QueryPositionReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryPositionReq)
  })
_sym_db.RegisterMessage(QueryPositionReq)

QueryPositionRsp = _reflection.GeneratedProtocolMessageType('QueryPositionRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryPositionRsp)
  })
_sym_db.RegisterMessage(QueryPositionRsp)

OrderInsertReq = _reflection.GeneratedProtocolMessageType('OrderInsertReq', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINSERTREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderInsertReq)
  })
_sym_db.RegisterMessage(OrderInsertReq)

OrderInsertRsp = _reflection.GeneratedProtocolMessageType('OrderInsertRsp', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINSERTRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderInsertRsp)
  })
_sym_db.RegisterMessage(OrderInsertRsp)

OrderCancelReq = _reflection.GeneratedProtocolMessageType('OrderCancelReq', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderCancelReq)
  })
_sym_db.RegisterMessage(OrderCancelReq)

OrderCancelRsp = _reflection.GeneratedProtocolMessageType('OrderCancelRsp', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderCancelRsp)
  })
_sym_db.RegisterMessage(OrderCancelRsp)

OrderCancelFailInfo = _reflection.GeneratedProtocolMessageType('OrderCancelFailInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELFAILINFO,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderCancelFailInfo)
  })
_sym_db.RegisterMessage(OrderCancelFailInfo)

OrderInfo = _reflection.GeneratedProtocolMessageType('OrderInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINFO,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderInfo)
  })
_sym_db.RegisterMessage(OrderInfo)

TradeReportInfo = _reflection.GeneratedProtocolMessageType('TradeReportInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRADEREPORTINFO,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.TradeReportInfo)
  })
_sym_db.RegisterMessage(TradeReportInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import json
from threading import Thread
from time import sleep

from ant_rpc import GatewayAuthenticator
from ant_rpc import Endpoint
from ant_rpc import Option
from ant_rpc import CommunicationType
from ant_rpc import ProtocolType
from ant_rpc import Client
from ant_rpc import Server
from ant_rpc import init_gateway_auth
from rpc_call_helper import rpc_call

from service_method import *


class Gateway(object):

    def __init__(self, ip, port, config_path):
        self._ip = ip
        self._port = port
        self._config_path = config_path
        self._client = None
        self._server = None
        self._option = Option()

    def connect(self):
        t = Thread(target=self._connect_gateway_with_auth)
        t.start()
        sleep(2)

    def _connect_gateway_with_auth(self):
        gateway_auth = GatewayAuthenticator()
        init_gateway_auth(gateway_auth, self._ip)

        self._client = Client(name=SERVICE_GATEWAY, need_ns=False, auth=gateway_auth)

        ep = Endpoint()
        ep.set_communication_type(CommunicationType.kCommunicationTcp)
        ep.set_ip(self._ip)
        ep.set_port(self._port)
        ep.set_protocol(ProtocolType.kProtocolGateway)
        ep.set_required_auth(True)

        self._client.append_endpoint(ep)

        self._client.set_on_create_channel(
            lambda conn: conn.get_codec().set_protocol_head(chr(0x0f)))

        self._server = Server('client_gateway')
        self._server.add_client(self._client)
        self._server.start(self._config_path)

        if self._client.sync_auth():
            pass
        else:
            print('gateway auth failed!')
            return

        self._server.wait()

    def get_server(self):
        return self._server

    def get_client(self):
        return self._client

    def gateway_call(self, service, method, req):
        self._option.set_forward_service_name(service)
        ret, rsp = rpc_call(SERVICE_GATEWAY, method, req, self._option)
        if method is METHOD_ACCOUNT_LOGIN and ret == 0:
            rsp_json = json.loads(rsp)
            investor_key = str(rsp_json['login']['investor_key'])
            channel_key = investor_key[0:-2]
            interface_type = int(investor_key[1:3])
            service_type = 2 ** interface_type
            self._option.set_channel_key(channel_key)
            self._option.set_service_type(service_type)

        return ret, rsp



# -*- coding: utf-8 -*-
import os
import inspect
import re
import json

with open(os.path.join(os.path.dirname(__file__), 'instrument.json'), 'r') as f:
    _instrument_list = json.load(f)

with open(os.path.join(os.path.dirname(__file__), 'station.json'), 'r') as f:
    _station_list = json.load(f)


def generate_req(frame):
    args, _, _, values = inspect.getargvalues(frame)
    req = dict()
    for arg_name in args:
        value = values[arg_name]
        if value is not None:
            req[arg_name] = value

    return req


def parse_exchange_id(instrument_id):
    ret = re.findall(r'^[a-zA-Z]+', instrument_id)
    instrument_code = ret[0].lower()
    for item in _instrument_list:
        # print(item)
        if instrument_code in _instrument_list[item]:
            return item
    else:
        raise Exception(u'非法的合约品种')


def parse_broker_info(broker_type, interface_type):
    if broker_type in _station_list and interface_type in _station_list[broker_type]['wt_info']:
        return _station_list[broker_type]['qsid'], _station_list[broker_type]['wt_info'][interface_type]
    else:
        raise Exception(u'请选择支持的期商及柜台')


if __name__ == '__main__':
    print(parse_exchange_id('ag2110'))
    print(parse_broker_info('SimNow', 'CTP'))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('\242\002\003COM'),
  serialized_pb=_b('\n\x0c\x63ommon.proto\x12\x06\x63ommon\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\x0c\")\n\x03Log\x12\x11\n\tlog_level\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x42\x06\xa2\x02\x03\x43OMb\x06proto3')
)




_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='common.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='common.Error.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='common.Error.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=62,
)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='common.Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_level', full_name='common.Log.log_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='common.Log.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=105,
)

DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Log'] = _LOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:common.Error)
  })
_sym_db.RegisterMessage(Error)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
  'DESCRIPTOR' : _LOG,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:common.Log)
  })
_sym_db.RegisterMessage(Log)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-

# 服务者名称[可包含多个服务]
SERVER_GATEWAY = "gateway"  # 网关服务
SERVER_ORDER_MANAGER = "order_manager"  # 订单管理
SERVER_TRADER = "trader"  # 交易进程
SERVER_QUANTS = "quants"  # 交易进程
SERVER_QUOTE_UT = "quote_ut"  # 行情-UT进程
SERVER_QUOTE_CTP = "quote_ctp"  # 行情-ctp进程
SERVER_MARKETDATA = "marketdata"  # 行情数据服务
SERVER_HQREALTIMEPUSH = "hqrealtimepush"  # 实时行情推送服务
SERVER_ACCOUNT = "account"  # 账户服务
SERVER_QUOTA = "quota"  # 行情查询服务

SERVER_DATA = "data"  # 数据(db)服务
SERVER_CONDITION = "condition"  # 条件服务
SERVER_NEST_CONDITION = "nest_condition"  # 嵌套条件单服务
SERVER_CONDITION_HTTP_GATEWAY = "condition_http_gateway"  # 条件单http服务网关
SERVER_ASSET = "asset"  # 资管服务
SERVER_ALGORITHM = "algorithm"  # 算法服务
SERVER_RISK = "risk"  # 风控服务
SERVER_GRID = "grid"  # 网格交易服务

SERVER_SIGNAL = "signal"  # 信号服务
SERVER_SIGNAL_CALC = "signal_calc"  # 信号计算服务

SERVER_STRATEGY = "strategy"  # 策略服务
SERVER_STRATEGY_CALC = "strategy_calc"  # 策略计算服务

SERVER_STOCKTHS = "transmid_stockths"  # 量化bus股票服务
SERVER_FORWARD = "forward"  # 转发服务
SERVER_WAREHOURSE = "warehourse"  # 分仓服务
SERVER_GRADECONDITION = "gradecondition"  # 分级条件单
SERVER_VERSION_MANAGER = "version_manager"  # 客户端版本管理
SERVER_CONFIGMANAGER = "configmanager"  # 配置管理模块
SERVER_MONITOR_CENTER = "monitor_center"  # 监控管理中心
SERVER_MONITOR_METRICS = "monitor_metrics"  # 监控指标转发中心
SERVER_MONITOR_RELAY = "monitor_relay"  # 监控指标转发中心/web请求中心

# 广播宏
TOPIC_MINDGO_SIGNAL = "topic.mindgo.signal"  # 信号推送
TOPIC_MONITOR = "topic.monitor"
TOPIC_TRADE = "topic.oms.trade"  # 成交推送
TOPIC_ORDER = "topic.oms.order"  # 委托推送
TOPIC_TRADE_FUTURES = "topic.trade.futures"  # 期货交易成交推送
TOPIC_ORDER_FUTURES = "topic.order.futures"  # 期货交易委托推送
TOPIC_TRADE_STOCK = "topic.trade.stock"  # 股票交易成交推送
TOPIC_ORDER_STOCK = "topic.order.stock"  # 股票交易委托推送

TOPIC_TRADE_CONDITION = "topic.trade.condition"  # 条件单交易成交推送
TOPIC_ORDER_CONDITION = "topic.order.condition"  # 条件单交易委托推送
TOPIC_TRIGGER_CONDITION = "topic.trigger.condition"  # 条件单触发推送
TOPIC_CHANGED_CONDITION = "topic.changed.condition"  # 条件单状态变更推送，成交，撤单，废单(已报，未报等中间状态不需要推送)

TOPIC_CHANGED_NEST_CONDITION = "topic.changed.nest_condition"  # 嵌套条件单变更推送

TOPIC_ORDER_POSITION = "topic.order.position"  # 仓位推送
TOPIC_ORDER_ACCOUNT_FUND = "topic.order.account.fund"  # 账户资金变动推送

TOPIC_QUOTE_TICK = "topic.quote.tick"  # 行情快照
TOPIC_QUOTE_TICK_FUTURES = "topic.quote.tick.futures"  # 期货快照
TOPIC_QUOTE_TICK_STOCK = "topic.quote.tick.stock"  # 股票快照

TOPIC_QUOTE_TRADE = "topic.quote.trade"  # 行情成交
TOPIC_QUOTE_ORDER = "topic.quote.order"  # 行情委托
TOPIC_QUOTE_ORDER_QUEUE = "topic.quote.order.queue"  # 行情委托队列

TOPIC_ORDER_CANCEL_FAILED = "topic.order.cancel.failed"  # 撤单失败推送
TOPIC_ACCOUNT_KILLED = "topic.account.killed"  # 账号被剔除事件
TOPIC_TRADE_ACCOUNT_KILLED = "topic.trade.account.killed"  # 资金账号被剔除事件
TOPIC_TRADE_ACCOUNT_LOGIN_NOTIFY = "topic.trade.account.login.notify"  # 资金账号登录事件通知
TOPIC_TRADE_ACCOUNT_LOGOUT_NOTIFY = "topic.trade.account.logout.notify"  # 资金账号全部登出事件通知
TOPIC_TRADE_ACCOUNT_LOGIN_FAILED_NOTIFY = "topic.trade.account.login_failed.notify"  # 资金账号登陆失败通知
TOPIC_QUERY_TRADING_ACCOUNT_TOKEN_NOTIFY = "topic.query.trading.account.token.notify"  # 查询监控中心令牌通知

TOPIC_SIGNAL_CLEANING = "topic.signal.cleaning"  # 信号清算事件
TOPIC_SIGNAL_STATUS_CHANGE = "topic.signal.status.change"  # 信号状态变更事件

TOPIC_SIGNAL_TRIGGER = "topic.signal.trigger"  # 信号触发事件
TOPIC_TRIGGER_PRICE_CHANGE = "topic.signal.trigger_price.change"  # 触发价变化事件

TOPIC_CLIENT_KILLED = "topic.client.killed"  # 客户端退出事件
TOPIC_CLIENT_CONNECTED = "topic.client.connected"  # 客户端连接事件
TOPIC_CLIENT_LOGIN = "topic.client.login"  # 用户登录事件
TOPIC_CLIENT_LOGOUT = "topic.client.logout"  # 用户登出事件
TOPIC_LOG_ELK = "topic.log.elk"  # 推送日志
TOPIC_GATAWAY_START = "topic.gateway.start"  # 网关启动事件

TOPIC_BANK_ACCOUNT_MONEY = "topic.bank.account.money"  # 银期查询余额通知
TOPIC_FROM_BANK_TO_FUTURE = "topic.from.bank.to.future"  # 银转期通知
TOPIC_FROM_FUTURE_TO_BANK = "topic.from.future.to.bank"  # 期转银通知

BROADCAST_GLOBAL = "broadcast.global"  # 全局广播标识

# 服务名称
SERVICE_TRADER_FUTURES = "rpc.trader.futures"  # 期货交易
SERVICE_TRADER_STOCK = "rpc.trader.stock"  # 股票交易
SERVICE_ORDER_MANAGER = "rpc.order.manager"  # 订单管理
SERVICE_TRADER_QUANTS = "rpc.trader.quants.service"  # 交易模块
SERVICE_CONDITION_GW = "rpc.condition.gw"  # 条件单网关服务

SERVICE_QUOTER_UT = "rpc.quoter.ut"  # 行情-ut
SERVICE_QUOTER_CTP = "rpc.quoter.ctp"  # 行情-ctp
SERVICE_MARKETDATA = "rpc.marketdata"  # 行情数据服务
SERVICE_HQREALTIMEPUSH = "rpc.hqrealtimepush"  # 实时行情推送服务
SERVICE_QUOTA = "rpc.quota"  # 行情咨询服务

SERVICE_ACCOUNT = "rpc.account"  # 账户
SERVICE_DATA = "rpc.data"  # 数据(db)服务
SERVICE_CONDITION = "rpc.condition"  # 条件服务(暂时无用)
SERVICE_CONDITION_FUTURE = "rpc.condition.futures"  # 期货条件单
SERVICE_NEST_CONDITION_FUTURE = "rpc.nest_condition.futures"  # 期货嵌套条件单
SERVICE_CONDITION_STOCK = "rpc.condition.stock"  # 股票条件单
SERVICE_ASSET = "rpc.asset"  # 资管服务
SERVICE_ALGORITHM = "rpc.algorithm"  # 算法服务
SERVICE_GRID = "rpc.grid"  # 网格交易服务
SERVICE_RISK = "rpc.risk"  # 风控服务

SERVICE_SIGNAL_MANAGER = "rpc.signal.manager"  # 信号服务管理
SERVICE_SIGNAL_CALC = "rpc.signal.calc"  # 信号计算服务

SERVICE_STRATEGY_CALC = "rpc.strategy.calc"  # 策略计算
SERVICE_STRATEGY_MANAGER = "rpc.strategy.manager"  # 策略服务

SERVICE_TRANSMID_STOCK = "rpc.transmid.service"  # 股票交易transmid
SERVICE_FORWARD = "rpc.forward"  # 转发服务
SERVICE_FORWARD_PRODUCT = "asset-product-api"  # 资管asset product服务
SERVICE_FORWARD_INSTITUTION = "asset-institution-api"  # 资管asset institution服务
SERVICE_WAREHOURSE = "rpc.warehourse"  # 分仓服务
SERVICE_GRADECONDITION = "rpc.gradecondition"  # "分级条件单"
SERVICE_VERSION_MANAGER = "rpc.version_manager"  # 客户端版本管理
SERVICE_CONFIGMANAGER = "rpc.configmanager"  # 配置管理模块
SERVICE_MONITORCENTER = "rpc.monitorcenter"  # 监控管理中心
SERVICE_MONITORCENTER_CONDITION = "rpc.monitorcenter.condition"  # 监控管理中心 条件单
SERVICE_MONITORMETRICS = "rpc.monitormetrics"  # 监控指标转发中心
SERVICE_MONITORRELAY = "rpc.monitorrelay"  # 监控指标转发中心
# 网关主动断线
SERVICE_GATEWAY = "gateway"  # 网关
METHOD_GATEWAY_ERROR = "gw_error"  # 网关错误事件

# 推送转发
SERVICE_PUSH_RELAY = "rpc.push.relay"  # 推送转发

# 分级条件单方法
METHOD_CREATE_GRADECONDITION = "create_gradecondition"  # 创建分级条件单
METHOD_CANCEL_GRADECONDITION = "cancel_gradecondition"  # 取消分级条件单
METHOD_DELETE_GRADECONDITION = "delete_gradecondition"  # 删除分级条件单
METHOD_PAUSE_GRADECONDITION = "pause_gradecondition"  # 暂停分级条件单
METHOD_ACTIVATE_GRADECONDITION = "activate_gradecondition"  # 激活分级条件单
METHOD_MODIFY_GRADECONDITION = "modify_gradecondition"  # 修改分级条件单
METHOD_QUERY_GRADECONDITION = "query_gradecondition"
METHOD_NEW_SUBJECT = "new_subject"  # 新增国债逆回购管理标的
METHOD_DELETE_SUBJECT = "delete_subject"  # 删除国债逆回购管理标的
METHOD_QUERY_SUBJECT = "query_subject"  # 查询国债逆回购管理标的
METHOD_MODIFY_SUBJECT = "modify_subject"  # 修改国债逆回购管理标的

# 分仓进程方法
METHOD_CREATE_WAREHOURSE = "create_warehourse"
# 创建分仓
METHOD_DELETE_WAREHOURSE = "delete_warehourse"
# 删除分仓
METHOD_QUERY_WAREHOURSE = "query_warehourse"
# 查询分仓
METHOD_MODIFY_WAREHOURSE = "modify_warehourse"
# 修改分仓
METHOD_TRY_WAREHOURSE = "try_warehourse"
# 调整分仓

# asset-api-protobuf 方法
METHOD_CELERY = "celery"  # 资管celery架构方法集
METHOD_GRAPH_QL = "graphql"  # 资管graphql架构方法集

# 转发进程方法
METHOD_QRY_ACCOUNTS = "qry_accounts"  # 查询账户
METHOD_ADD_ACCOUNT = "add_account"  # 新增账户
METHOD_DEL_ACCOUNT = "del_account"  # 删除账户
METHOD_BIND_ACCOUNT = "bind_account"  # 绑定账户
METHOD_UNBIND_ACCOUNT = "unbind_account"  # 解绑账户
METHOD_QRY_BIND = "qry_bindaccount"  # 查询绑定
METHOD_BATCH_MODIFY = "batch_modifyaccount"  # 批量修改账户
METHOD_ADD_BWLIST = "add_bwlist"  # 创建白名单
METHOD_UPDATE_BWLIST = "update_bwlist"  # 更新白名单
METHOD_DEL_BWLIST = "del_bwlist"  # 删除白名单
METHOD_QRY_BWLIST = "qry_bwlist"  # 查询白名单
METHOD_QRY_INSTITUTION = "qry_institution"  # 查询单个机构
METHOD_QRY_INSTITUTIONS = "qry_institutions"  # 查询多个机构
METHOD_UPDATE_INSTITUTION = "update_institution"  # 修改机构白名单
METHOD_CAN_LOGIN = "can_login"  # 判断是否能登录
METHOD_BATCH_DEL_ACCOUNTS = "batch_del_accounts"  # 批量删除账户

# 交易进程 方法
METHOD_TRADER_LOGIN = "login"  # 登录
METHOD_TRADER_LOGOUT = "logout"  # 登出
METHOD_TRADER_QUERY_INVESTOR = "query_investor"  # 查询投资者
METHOD_TRADER_CONFIRM_SETTLEMENT_INFO = "confirm_settlement_info"  # 确认结算单
METHOD_TRADER_QUERY_SETTLEMENT_INFO = "query_settlement_info"  # 查询投资者结算结果
METHOD_TRADER_QUERY_SETTLEMENT_INFO_CONFIRM = "query_settlement_confirm"  # 查询投资者结算确认
METHOD_TRADER_QUERY_ASSET = "query_asset"  # 查询资金
METHOD_TRADER_QUERY_ORDER = "query_order"  # 查询委托
METHOD_TRADER_QUERY_TRADE = "query_trade"  # 查询成交
METHOD_TRADER_QUERY_POSITION = "query_position"  # 查询持仓
METHOD_TRADER_QUERY_POSITION_DETAIL = "query_position_detail"  # 查询持仓明细
METHOD_TRADER_QUERY_COMMISSION_RATE = "query_commission_rate"  # 查询手续费率
METHOD_TRADER_QUERY_MARGIN_RATE = "query_margin_rate"  # 查询保证金费率
METHOD_TRADER_INSERT_ORDER = "insert_order"  # 委托
METHOD_TRADER_CANCEL_ORDER = "cancel_order"  # 撤单
METHOD_TRADER_BATCH_INSERT_ORDER = "batch_insert_order"  # 批量委托
METHOD_TRADER_BATCH_CANCEL_ORDER = "batch_cancel_order"  # 批量撤单
METHOD_TRADER_QUERY_INSTRUMENT = "query_instrument"  # 查询合约
METHOD_TRADER_USER_PASSWORD_UPDATE = "user_password_update"  # 修改密码
METHOD_TRADER_QUERY_MAX_ORDER_VOLUME = "query_max_order_volume"  # 查询最大报单数量请求
METHOD_TRADER_QUERY_TRADING_CODE = "query_trading_code"  # 查询交易编码
METHOD_TRADER_QUERY_NOTICE = "query_notice"  # 查询客户通知
METHOD_TRADER_QUERY_TRADING_NOTICE = "query_trading_notice"  # 查询交易通知
METHOD_TRADER_QUERY_CFMMC_ACCOUNT_TOKEN = "query_cfmmc_account_token"  # 查询监控中心用户令牌

# 条件单http网关方法
METHOD_CONDITION_GW_LOGIN = "login"  # 登录
METHOD_CONDITION_GW_CONDITION_ZL = "conditionzl"  # 请求统一方法
METHOD_CONDITION_GW_CONDITION = "condition"  # 请求统一方法

# 条件单进程方法
METHOD_CONDITION_ORDER_INSERT = "condition_order_insert"  # 新增条件单
METHOD_CONDITION_ORDER_MODIFY = "condition_order_modify"  # 修改条件单
METHOD_CONDITION_ORDER_PAUSE = "condition_order_pause"  # 暂停条件单
METHOD_CONDITION_ORDER_ACTIVATE = "condition_order_activate"  # 激活条件单
METHOD_CONDITION_ORDER_DELETE = "condition_order_delete"  # 删除条件单
METHOD_CONDITION_ORDER_QUERY = "condition_order_query"  # 查询单笔条件单
METHOD_CONDITION_ORDER_MULTIQUERY = "condition_order_multiquery"  # 查询多笔条件单
METHOD_CONDITION_ORDER_CANCEL = "condition_order_cancel"  # 取消条件单
METHOD_CONDITION_SETTLE = "condition_settle"  # 处理条件单日终日初

# 嵌套条件单进程方法
METHOD_NEST_CONDITION_INSERT = "nest_condition_insert"  # 新增嵌套条件单
METHOD_NEST_CONDITION_QUERY = "nest_condition_query"  # 条件单查询（附带嵌套条件单信息）
METHOD_NEST_CONDITION_MODIFY = "nest_condition_modify"  # 修改嵌套条件单

# 订单管理 方法
METHOD_ORDER_QUERY_ASSET = "query_asset"  # 查询资产
METHOD_ORDER_QUERY_ORDER = "query_order"  # 查询委托
METHOD_ORDER_QUERY_TRADE = "query_trade"  # 查询成交
METHOD_ORDER_QUERY_POSITION = "query_position"  # 查询持仓
METHOD_ORDER_QUERY_POSITION_DETAIL = "query_position_detail"  # 查询持仓明细
METHOD_ORDER_QUERY_COMMISSION_RATE = "query_commission_rate"  # 查询手续费率
METHOD_ORDER_QUERY_MARGIN_RATE = "query_margin_rate"  # 查询保证金费率
METHOD_ORDER_QUERY__RATE = "query_rate"  # 查询费率
METHOD_ORDER_INSERT_ORDER = "insert_order"  # 委托
METHOD_ORDER_CANCEL_ORDER = "cancel_order"  # 撤单
METHOD_ORDER_BATCH_INSERT_ORDER = "batch_insert_order"  # 批量委托
METHOD_ORDER_BATCH_CANCEL_ORDER = "batch_cancel_order"  # 批量撤单
METHOD_ORDER_INSERT_ORDER_T = "insert_order_t"  # 委托（兼容指令模块，预计2020年10月份删除）
METHOD_ORDER_CANCEL_ORDER_T = "cancel_order_t"  # 撤单（兼容指令模块，预计2020年10月份删除）
METHOD_ORDER_INSERT_ORDER_JGB = "insert_order_jgb"  # 委托（兼容机构版普通下单）

# 行情进程 方法
METHOD_QUOTER_QUERY_LAST_QUOTE = "query_last_quote"  # 查询最新快照
METHOD_QUOTER_SUB_LAST_QUOTE = "subscribe_last_quote"  # 订阅最新行情
METHOD_QUOTER_UNSUB_LAST_QUOTE = "unsubscribe_last_quote"  # 取消订阅最新行情
METHOD_QUOTER_SUB_TICK_QUOTE = "subscribe_tick_quote"  # 订阅逐笔行情
METHOD_QUOTER_UNSUB_TICK_QUOTE = "unsubscribe_tick_quote"  # 取消订阅逐笔行情
METHOD_QUOTER_SUB_TRADE = "subscribe_trade"  # 订阅成交
METHOD_QUOTER_UNSUB_TRADE = "unsubscribe_trade"  # 取消订阅成交
METHOD_QUOTER_SUB_ORDER = "subscribe_order"  # 订阅委托
METHOD_QUOTER_UNSUB_ORDER = "unsubscribe_order"  # 取消订阅委托
METHOD_QUOTER_SUB_ORDER_QUEUE = "subscribe_order_queue"  # 订阅委托队列
METHOD_QUOTER_UNSUB_ORDER_QUEUE = "unsubscribe_order_queue"  # 取消订阅委托队列
METHOD_QUOTER_QUERY_MAX_ACTIVE_INSTRUMENT = "query_max_active_instrument"  # 查询主力合约
METHOD_QUOTER_QUERY_INSTRUMENT = "query_instrument"  # 查询合约
METHOD_QUOTER_QUERY_SECURITY = "query_security"  # 查询证券

# 行情数据 方法
METHOD_MD_QUERY_LAST_QUOTE = "query_last_quote"  # 查询最新行情
METHOD_MD_QUERY_MAX_ACTIVE_INSTRUMENT = "query_max_active_instrument"  # 查询主力合约
METHOD_MD_QUERY_INSTRUMENT = "query_instrument"  # 查询合约
METHOD_MD_QUERY_SECURITY = "query_security"  # 查询证券
METHOD_MD_QUERY_BAR_DATA = "query_bar_data"  # 查询k线数据
METHOD_MD_QUERY_SHARES_DATA = "query_shares_data"  # 查询新股数据
METHOD_MD_QUERY_BILLBOARD_DATA = "query_billboard_data"  # 查询龙虎榜数据
METHOD_MD_QUERY_BATCH_BAR_DATA = "query_batch_bar_data"  # 批量查询k线数据
METHOD_MD_QUERY_TRADE_DAY = "query_trading_day"  # 查询交易日
METHOD_MD_QUERY_TICK_DETAIL = "query_tick_detail"  # 查询成交明细

# 账户进程 方法
METHOD_ACCOUNT_USER_AUTH = "user_auth"  # 客户端验证
METHOD_ACCOUNT_LOGIN = "login"  # 资金账户登录
METHOD_ACCOUNT_LOGOUT = "logout"  # 资金账户登出
METHOD_ACCOUNT_QUERY_ACCOUNT = "query_account"  # 查询资金账户数据
METHOD_ACCOUNT_QUERY_ACCOUNT_LIST = "query_account_list"  # 查询资金账户列表
METHOD_ACCOUNT_QUERY_LOGINED_ACCOUNTS = "query_logined_accounts"  # 查询已登录资金账户列表
METHOD_ACCOUNT_DELETE = "delete"  # 删除资金账户

# 信号进程 方法
METHOD_SIGNAL_SUBSCRIBE = "subscribe"  # 信号订阅
METHOD_SIGNAL_UNSUBSCRIBE = "unsubscribe"  # 信号取消订阅
METHOD_SIGNAL_HEALTH_CHECK = "health_check"  # 保活信息

# 策略管理进程 方法
METHOD_STRATEGY_START_PROCESS = "start_process"  # 启动策略进程
METHOD_STRATEGY_STOP_PROCESS = "stopc_process"  # 停止策略进程
METHOD_STRATEGY_QUERY_ALIVE_PROCESS_LIST = "query_alive_process_list"  # 查询正在运行的策略列表
METHOD_STRATEGY_HEALTH_CHECK = "health_check"  # 进程保活

# transmid
METHOD_TRANSMID_TRADER_LOGIN = "trader_login"  # 登录
METHOD_TRANSMID_TRADER_LOGOUT = "trader_logout"  # 登出
METHOD_TRANSMID_TRADER_QUERY_ASSET = "trader_query_asset"  # 查询资产
METHOD_TRANSMID_TRADER_QUERY_ORDER = "trader_query_orders"  # 查询委托
METHOD_TRANSMID_TRADER_QUERY_TRADE = "trader_query_traders"  # 查询成交
METHOD_TRANSMID_TRADER_QUERY_POSITION = "trader_query_position"  # 查询持仓
METHOD_TRANSMID_TRADER_INSERT_ORDER = "trader_insert_order"  # 委托
METHOD_TRANSMID_TRADER_CANCEL_ORDER = "trader_cancel_order"  # 撤单

# 银期转账
METHOD_TRADER_TRADING_ACCOUNT_PASSWORD_UPDATE = "trading_account_password_update"  # 资金账户口令更新请求
METHOD_TRADER_QUERY_CONTRACT_BANK = "query_contract_bank"  # 查签约银行
METHOD_TRADER_QUERY_ACCOUNT_REGISTER = "query_account_register"  # 查询银期签约关系
METHOD_TRADER_QUERY_TRANSFER_SERIAL = "query_transfer_serial"  # 查询转帐流水
METHOD_TRADER_QUERY_BANK_ACCOUNT_MONEY = "query_bank_account_money"  # 查询银行余额
METHOD_TRADER_FROM_BANK_TO_FUTURE = "from_bank_to_future"  # 银行资金转期货
METHOD_TRADER_FROM_FUTURE_TO_BANK = "from_future_to_bank"  # 期货资金转银行

# 风控服务
METHOD_RISK_VIARISK = "viarisk"  # 风控校验

# 客户端版本管理方法
METHOD_VERSION_MANAGER_INSERT = "insert"  # 新增版本
METHOD_VERSION_MANAGER_MODIFY = "modify"  # 修改版本
METHOD_VERSION_MANAGER_GO_ONLINE = "go_online"  # 上线版本
METHOD_VERSION_MANAGER_SET_BLACKLIST = "set_blacklist"  # 设置黑名单
METHOD_VERSION_MANAGER_QUERY = "query"  # 查询版本信息
METHOD_VERSION_MANAGER_DELETE = "delete"  # 删除版本
METHOD_VERSION_MANAGER_QUERY_ONLINE = "query_online"  # 查询线上版本
METHOD_VERSION_MANAGER_QUERY_SERVICE = "query_service"  # 查询服务器列表
METHOD_VERSION_MANAGER_INSERT_SERVICE = "insert_service"  # 新增服务器
METHOD_VERSION_MANAGER_DELETE_SERVICE = "delete_service"  # 删除服务器
METHOD_VERSION_MANAGER_INSERT_PRODUCT = "insert_product"  # 新增客户端类型
METHOD_VERSION_MANAGER_DELETE_PRODUCT = "delete_product"  # 删除客户端类型
METHOD_VERSION_MANAGER_QUERY_PRODUCT = "query_product"  # 查询客户端类型
METHOD_VERSION_MANAGER_QUERY_USER_VERSION = "query_user_version"  # 查询指定用户客户端版本绑定
METHOD_VERSION_MANAGER_SET_USER_VERSION = "set_user_version"  # 设置指定用户客户端版本绑定
METHOD_VERSION_MANAGER_MODIFY_USER_VERSION = "modify_user_version"  # 修改指定用户客户端版本绑定
METHOD_VERSION_MANAGER_DELETE_USER_VERSION = "delete_user_version"  # 删除指定用户客户端版本绑定

# 配置管理模块
METHOD_QUERY_CONFIG = "query_config"
# 监控管理中心
METHOD_QUERY_TARGETVALUE = "query_target_value"
# 监控客户端
CLIENT_MONITOR_RELAY_NODE = "monitor_relay_node"
METHOD_MONITOR_QUERY_METRICS = "query"  # 转发模块支持查询接口



# -*- coding: utf-8 -*-
import json
import base64

try:
    from trade.trade_futures_pb2 import OrderInfo
    from trade.trade_futures_pb2 import TradeReportInfo
    from quote.quote_pb2 import NotificationTick
    from google.protobuf import json_format
except Exception as e:
    print(u'缺少依赖库，订阅推送类业务将无法正常使用')

from gateway import Gateway

from service_method import *
import account_req_helper as account
import trade_req_helper as trade
import quote_req_helper as quote

from comm_utils import parse_exchange_id, parse_broker_info


class BrokerType(object):
    SimNow = 'SimNow'
    SimTrade = 'SimTrade'


class PlatformType(object):
    SIMULATE = 'SIMULATE'
    CTP = 'CTP'
    UFX = 'UFX'
    KSFT = 'KSFT'


class TradeClient(object):

    def __init__(self, inter_service):
        self._investor_key = None
        self._rpc_call = None
        self._inter_service = None
        if isinstance(inter_service, Gateway):  # 暂时只支持网关接入
            self._inter_service = inter_service
            self._rpc_call = self._inter_service.gateway_call
        else:
            raise Exception('not supported service type')

    def start(self):
        self._inter_service.connect()

    def subscribe_trade(self, func):
        self._inter_service.get_client().register_cb(TOPIC_TRADE_FUTURES,
                                                     lambda base64_msg: self._inner_cb(base64_msg, TradeReportInfo(),
                                                                                       func))
        self._inter_service.get_client().subscribe(TOPIC_TRADE_FUTURES)

    def unsubscribe_trade(self):
        self._inter_service.get_client().unsubscribe(TOPIC_TRADE_FUTURES)

    def subscribe_order(self, func):
        self._inter_service.get_client().register_cb(TOPIC_ORDER_FUTURES,
                                                     lambda base64_msg: self._inner_cb(base64_msg, OrderInfo(), func))
        self._inter_service.get_client().subscribe(TOPIC_ORDER_FUTURES)

    def unsubscribe_order(self):
        self._inter_service.get_client().unsubscribe(TOPIC_ORDER_FUTURES)

    def login(self,
              investor_id,
              trade_password,
              broker_type,
              interface_type
              ):
        trade_login_req = trade.make_login_req(investor_id=investor_id,
                                               trade_password=trade_password,
                                               op_station=None,
                                               interface_type=None,
                                               account_type=trade.AccountType.AccountType_FUTURES,
                                               broker_id=None,
                                               user_product_info=None,
                                               app_id=None,
                                               auth_code=None,
                                               collect_info=None,
                                               flow_path=None,
                                               client_public_ip=None,
                                               client_port=None,
                                               md_op_station=None,
                                               client_id=None,
                                               client_info=None,
                                               is_auto_confirm=None,
                                               is_sync_position=None,
                                               is_check_pwd=None,
                                               op_station_off=None)
        try:
            qsid, wtid = parse_broker_info(broker_type, interface_type)
        except Exception as e:
            print(e)
            return False

        req = account.make_login_req(login=trade_login_req, qsid=qsid, wtid=wtid)

        ret, rsp = self._rpc_call(SERVICE_ACCOUNT, METHOD_ACCOUNT_LOGIN, req)

        if ret == 0:
            rsp_json = json.loads(rsp)
            self._investor_key = rsp_json['login']['investor_key']
            return True
        else:
            print('login failed, msg:%s', rsp)
            return False

    def logout(self):
        if self._investor_key is None:
            return -1, 'please login first!'

        account_logout_req = account.make_logout_req(investor_key=self._investor_key)
        return self._rpc_call(SERVICE_ACCOUNT, METHOD_ACCOUNT_LOGOUT, account_logout_req)

    def query_asset(self,
                    currency_id=None,
                    biz_type=None,
                    account_id=None,
                    client_id=None,
                    trading_day=None):
        req = trade.make_query_asset_req(investor_key=self._investor_key,
                                         currency_id=currency_id,
                                         biz_type=biz_type,
                                         account_id=account_id,
                                         client_id=client_id,
                                         trading_day=trading_day)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ASSET, req)

    def query_order(self,
                    instrument_id=None,
                    exchange_id=None,
                    order_sys_id=None,
                    insert_time_start=None,
                    insert_time_end=None,
                    client_id=None):
        if instrument_id is not None:
            exchange_id = parse_exchange_id(instrument_id)

        req = trade.make_query_order_req(investor_key=self._investor_key,
                                         instrument_id=instrument_id,
                                         exchange_id=exchange_id,
                                         order_sys_id=order_sys_id,
                                         insert_time_start=insert_time_start,
                                         insert_time_end=insert_time_end,
                                         client_id=client_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ORDER, req)

    def query_position_detail(self,
                              instrument_id=None,
                              exchange_id=None,
                              historical_date=None,
                              type=None):
        req = trade.make_query_position_detail_req(investor_key=self._investor_key,
                                                   instrument_id=instrument_id,
                                                   exchange_id=exchange_id,
                                                   historical_date=historical_date,
                                                   type=type)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_POSITION_DETAIL, req)

    def order_insert(self, instrument_id,
                     direction,
                     comb_offset_flag,
                     volume_total_original,
                     order_no=None,
                     order_price_type=trade.OrderPriceType.OrderPriceType_LimitPrice,
                     limit_price=None,  # 根据order_price_type类型填写
                     comb_hedge_flag='0',  # 投机
                     time_condition=trade.TimeConditionType.TimeConditionType_GFD,
                     gtd_date=None,
                     volume_condition=None,
                     min_volume=None,
                     contingent_condition=None,
                     stop_price=None,
                     force_close_reason=None,
                     user_force_close=None,
                     is_swap_order=None,
                     local_order_no=None,
                     client_id=None,
                     source=None,
                     is_back_hand=None,
                     is_change_order=None,
                     new_order_price_type=None,
                     new_limit_price=None,
                     price_tick_num=None):
        exchange_id = parse_exchange_id(instrument_id)
        if order_price_type is trade.OrderPriceType.OrderPriceType_LimitPrice and limit_price is None:
            return -1, u'价格类型为限价，请填写价格'

        req = trade.make_order_insert_req(investor_key=self._investor_key,
                                          instrument_id=instrument_id,
                                          order_no=order_no,
                                          order_price_type=order_price_type,
                                          direction=direction,
                                          comb_offset_flag=comb_offset_flag,
                                          comb_hedge_flag=comb_hedge_flag,
                                          limit_price=limit_price,
                                          volume_total_original=volume_total_original,
                                          time_condition=time_condition,
                                          gtd_date=gtd_date,
                                          volume_condition=volume_condition,
                                          min_volume=min_volume,
                                          contingent_condition=contingent_condition,
                                          stop_price=stop_price,
                                          force_close_reason=force_close_reason,
                                          user_force_close=user_force_close,
                                          is_swap_order=is_swap_order,
                                          exchange_id=exchange_id,
                                          local_order_no=local_order_no,
                                          client_id=client_id,
                                          source=source,
                                          is_back_hand=is_back_hand,
                                          is_change_order=is_change_order,
                                          new_order_price_type=new_order_price_type,
                                          new_limit_price=new_limit_price,
                                          price_tick_num=price_tick_num)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_INSERT_ORDER, req)

    def order_cancel(self,
                     order_no,
                     cancel_order_no=None,
                     order_sys_id=None,
                     instrument_id=None,
                     investor_id=None,
                     client_id=None,
                     is_change_order=None,
                     volume_total_original=None,
                     order_price_type=None,
                     limit_price=None,
                     price_tick_num=None):
        exchange_id = parse_exchange_id(instrument_id)
        req = trade.make_order_cancel_req(investor_key=self._investor_key,
                                          cancel_order_no=cancel_order_no,
                                          order_no=order_no,
                                          exchange_id=exchange_id,
                                          order_sys_id=order_sys_id,
                                          instrument_id=instrument_id,
                                          investor_id=investor_id,
                                          client_id=client_id,
                                          is_change_order=is_change_order,
                                          volume_total_original=volume_total_original,
                                          order_price_type=order_price_type,
                                          limit_price=limit_price,
                                          price_tick_num=price_tick_num)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_CANCEL_ORDER, req)

    def query_instrument(self,
                         instrument_id=None):
        exchange_id = parse_exchange_id(instrument_id)
        req = trade.make_query_instrument_req(investor_key=self._investor_key,
                                              exchange_id=exchange_id,
                                              instrument_id=instrument_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_INSTRUMENT, req)

    def query_last_quote(self,
                         instrument_id,
                         instrument_type=quote.InstrumentType.InstrumentType_Future):
        exchange_id = parse_exchange_id(instrument_id)
        req = quote.make_query_last_quote_req(exchange_id=exchange_id, instrument_id=instrument_id,
                                              instrument_type=instrument_type)
        return self._rpc_call(SERVICE_QUOTA, METHOD_MD_QUERY_LAST_QUOTE, req)

    def query_bar_data(self,
                       instrument_id,
                       date=None,
                       instrument_type=quote.InstrumentType.InstrumentType_Future,
                       bar_type=quote.BarType.BarType_Min,
                       start_time=None,
                       end_time=None,
                       ):
        exchange_id = parse_exchange_id(instrument_id)
        req = quote.make_query_bar_data_req(exchange_id=exchange_id, instrument_id=instrument_id, date=date,
                                            instrument_type=instrument_type, bar_type=bar_type, start_time=start_time,
                                            end_time=end_time)
        return self._rpc_call(SERVICE_QUOTA, METHOD_MD_QUERY_LAST_QUOTE, req)

    def subscribe_quote(self,
                        func,
                        instrument_id,
                        instrument_type=quote.InstrumentType.InstrumentType_Future):

        self._inter_service.get_client().register_cb(TOPIC_QUOTE_TICK,
                                                     lambda base64_msg: self._inner_cb(base64_msg, NotificationTick(),
                                                                                       func))
        self._inter_service.get_client().subscribe(TOPIC_QUOTE_TICK)
        exchange_id = parse_exchange_id(instrument_id)
        req = quote.make_subscribe_quote_req(exchange_id=exchange_id, instrument_id=instrument_id,
                                             instrument_type=instrument_type)
        ret, rsp = self._rpc_call(SERVICE_MARKETDATA, METHOD_QUOTER_SUB_LAST_QUOTE, req)
        print(rsp)

    def unsubscribe_quote(self,
                          instrument_id,
                          instrument_type=quote.InstrumentType.InstrumentType_Future):
        exchange_id = parse_exchange_id(instrument_id)
        req = quote.make_unsubscribe_quote_req(exchange_id=exchange_id, instrument_id=instrument_id,
                                               instrument_type=instrument_type)
        self._rpc_call(SERVICE_MARKETDATA, METHOD_QUOTER_UNSUB_LAST_QUOTE, req)
        self._inter_service.get_client().unsubscribe(TOPIC_QUOTE_TICK)

    def _inner_cb(self, base64_msg, msg_obj, func):
        msg_bytes = base64.decodebytes(bytes(base64_msg, encoding='utf-8'))

        msg_obj.ParseFromString(msg_bytes)
        msg = json_format.MessageToJson(msg_obj, preserving_proto_field_name=True)
        func(msg)



# -*- coding: utf-8 -*-

from ant_rpc import Option


def make_login_req(login, client_id='', qsid='', wtid=''):
    req = dict()
    req['client_id'] = client_id
    req['login'] = login
    req['qsid'] = qsid
    req['wtid'] = wtid

    return req


def make_logout_req(investor_key, client_id=''):
    req = dict()
    req['investor_key'] = investor_key
    req['client_id'] = client_id

    return req
